.. This file is a part of the AnyBlok project
..
..    Copyright (C) 2015 Jean-Sebastien SUZANNE <jssuzanne@anybox.fr>
..
.. This Source Code Form is subject to the terms of the Mozilla Public License,
.. v. 2.0. If a copy of the MPL was not distributed with this file,You can
.. obtain one at http://mozilla.org/MPL/2.0/.

API doc
~~~~~~~

**exceptions**

.. automodule:: anyblok.bloks.io_csv.exceptions

.. autoexception:: CSVImporterException
    :members:
    :undoc-members:
    :show-inheritance:
    :noindex:

.. autoexception:: CSVExporterException
    :members:
    :undoc-members:
    :show-inheritance:
    :noindex:

**mixin**

.. automodule:: anyblok.bloks.io_csv.mixin

.. autoclass:: IOCSVFieldMixin
    :members:
    :undoc-members:
    :show-inheritance:
    :noindex:

.. autoclass:: IOCSVMixin
    :members:
    :undoc-members:
    :show-inheritance:
    :noindex:

**importer**

.. automodule:: anyblok.bloks.io_csv.importer

.. autoclass:: Importer
    :members:
    :undoc-members:
    :show-inheritance:
    :noindex:

.. autoclass:: CSV
    :members:
    :undoc-members:
    :show-inheritance:
    :noindex:

**exporter**

.. automodule:: anyblok.bloks.io_csv.exporter

.. autoclass:: Exporter
    :members:
    :undoc-members:
    :show-inheritance:
    :noindex:

.. autoclass:: Field
    :members:
    :undoc-members:
    :show-inheritance:
    :noindex:

.. autoclass:: CSV
    :members:
    :undoc-members:
    :show-inheritance:
    :noindex:
